csep.core.forecasts.CatalogForecast
===================================

.. currentmodule:: csep.core.forecasts

.. autoclass:: CatalogForecast

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CatalogForecast.__init__
      ~CatalogForecast.get_dataframe
      ~CatalogForecast.get_expected_rates
      ~CatalogForecast.load_ascii
      ~CatalogForecast.magnitude_counts
      ~CatalogForecast.spatial_counts
      ~CatalogForecast.write_ascii
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CatalogForecast.end_epoch
      ~CatalogForecast.log
      ~CatalogForecast.magnitudes
      ~CatalogForecast.min_magnitude
      ~CatalogForecast.start_epoch
   
   